@@ -26,14 +26,20 @@
    This work has the LPPL maintenance status `maintained'.
   
    History:
-   * 1.2
+   * 4.34:
+     - added check for \glsxtr@resource
+   * 4.33:
+     - Version number synchronized with glossaries.sty
+   * 1.3
+     - added check for \glsxtr@makeglossaries
+   * 1.2 (2016-05-27)
      - added check for \@gls@extramakeindexopts
      - added check for nil codepage
    * 1.1
      - changed first line from lua to texlua
 --]]
 
-thisversion = "1.2 2016-05-27"
+thisversion = "4.34 2017-11-03"
 
 quiet = false
 dryrun = false
@@ -45,6 +51,8 @@ logfile = nil
 
 isxindy = false
 
+isbib2gls = false
+
 xindylang = nil
 xindyexec = "xindy"
 
@@ -325,18 +333,31 @@ assert(io.input(auxfile),
 
 aux = io.read("*a")
 
+if string.find(aux, "\\glsxtr@resource") ~= nil
+then
+  isbib2gls = true
+end
+
 if styfile == nil
 then
   styfile = string.match(aux, "\\@istfilename{\"?([^}]*%.?%a*)\"?}")
 
   if styfile == nil
   then
-    error([[
+    if isbib2gls
+    then
+       error([[
+No \@istfilename found but found \glsxtr@resource.
+You need to run bib2gls not makeglossaries-lite.
+  ]])
+    else
+       error([[
 No \@istfilename found.
 Did your LaTeX run fail?
 Did your LaTeX run produce any output?
 Did you remember to use \makeglossaries?
   ]])
+    end
   end
 end
 
@@ -399,6 +420,22 @@ for name, glg, gls, glo in
 
 end
 
+onlytypes = string.match(aux, "\\glsxtr@makeglossaries{([^}]+)}")
+
+if onlytypes ~= nil
+then
+  if not quiet then
+    print(string.format("Only process subset: '%s'", onlytypes))
+  end
+
+  onlyglossaries = {}
+
+  for name in string.gmatch(onlytypes, '([^,]+)') do
+     onlyglossaries[name] = glossaries[name]
+  end
+
+  glossaries = onlyglossaries
+end
 
 if ext == nil
 then
